@@ -41,7 +41,7 @@ mod impls {
             self.inner.supported_protocol_versions()
         }
 
-        fn is_stateful(&self) -> bool {
+        fn connection_persists_across_multiple_requests(&self) -> bool {
             self.stateful
         }
     }
@@ -83,7 +83,7 @@ mod impls {
             self.inner.supported_protocol_versions()
         }
 
-        fn is_stateful(&self) -> bool {
+        fn connection_persists_across_multiple_requests(&self) -> bool {
             self.stateful
         }
     }
